Skip site navigation (1)Skip section navigation (2)
Date:      Tue, 23 Jan 2024 10:30:29 GMT
From:      Lorenzo Salvadore <salvadore@FreeBSD.org>
To:        ports-committers@FreeBSD.org, dev-commits-ports-all@FreeBSD.org, dev-commits-ports-main@FreeBSD.org
Subject:   git: c48fd2014e72 - main - emulators/emulationstation: Update to v2.11.2
Message-ID:  <202401231030.40NAUTtK038742@gitrepo.freebsd.org>

next in thread | raw e-mail | index | archive | help
The branch main has been updated by salvadore:

URL: https://cgit.FreeBSD.org/ports/commit/?id=c48fd2014e721f0e4b3a76ef30c2592b75ac85e9

commit c48fd2014e721f0e4b3a76ef30c2592b75ac85e9
Author:     Lorenzo Salvadore <salvadore@FreeBSD.org>
AuthorDate: 2023-12-26 15:54:03 +0000
Commit:     Lorenzo Salvadore <salvadore@FreeBSD.org>
CommitDate: 2024-01-23 10:30:25 +0000

    emulators/emulationstation: Update to v2.11.2
    
    This also fixes the build with GCC 13 [1].
    
    Changes:
    https://github.com/RetroPie/EmulationStation/compare/v2.9.4...v2.11.2
    
    PR:             273676 [1]
    Approved by:    maintainer timeout (> 3 weeks)
---
 emulators/emulationstation/Makefile                |  9 +-
 emulators/emulationstation/distinfo                |  6 +-
 .../files/patch-es-app_src_SystemData.h            | 11 +++
 .../patch-es-core_src_utils_FileSystemUtil.cpp     | 96 ++++++++++++++++------
 .../files/patch-es-core_src_utils_TimeUtil.h       | 10 ---
 emulators/emulationstation/pkg-plist               |  1 +
 6 files changed, 91 insertions(+), 42 deletions(-)

diff --git a/emulators/emulationstation/Makefile b/emulators/emulationstation/Makefile
index 9c98e11b0cd0..6406b70c7395 100644
--- a/emulators/emulationstation/Makefile
+++ b/emulators/emulationstation/Makefile
@@ -1,7 +1,6 @@
 PORTNAME=	emulationstation
 DISTVERSIONPREFIX=	v
-DISTVERSION=	2.9.4
-PORTREVISION=	5
+DISTVERSION=	2.11.2
 CATEGORIES=	emulators
 
 MAINTAINER=	freebsd@coombscloud.com
@@ -13,7 +12,8 @@ LICENSE_COMB=	multi
 LICENSE_FILE_APACHE20=	${WRKSRC}/opensans_license.txt
 LICENSE_FILE_MIT=	${WRKSRC}/LICENSE.md
 
-BUILD_DEPENDS=	${LOCALBASE}/include/rapidjson/document.h:devel/rapidjson
+BUILD_DEPENDS=	${LOCALBASE}/include/rapidjson/document.h:devel/rapidjson \
+		pugixml>0:textproc/pugixml
 LIB_DEPENDS=	libboost_date_time.so:devel/boost-libs \
 		libboost_filesystem.so:devel/boost-libs \
 		libboost_locale.so:devel/boost-libs \
@@ -24,10 +24,11 @@ LIB_DEPENDS=	libboost_date_time.so:devel/boost-libs \
 		libpugixml.so:textproc/pugixml \
 		libvlc.so:multimedia/vlc
 
-USES=		cmake compiler:gcc-c++11-lib gl pkgconfig sdl
+USES=		cmake gl pkgconfig sdl
 USE_GITHUB=	yes
 GH_ACCOUNT=	RetroPie
 GH_PROJECT=	EmulationStation
+USE_GCC=	yes
 USE_GL=		gl glu
 USE_SDL=	sdl2
 
diff --git a/emulators/emulationstation/distinfo b/emulators/emulationstation/distinfo
index 76331844b151..2379fe34d5cb 100644
--- a/emulators/emulationstation/distinfo
+++ b/emulators/emulationstation/distinfo
@@ -1,3 +1,3 @@
-TIMESTAMP = 1606557422
-SHA256 (RetroPie-EmulationStation-v2.9.4_GH0.tar.gz) = 79452f6c1e8aaebe98c19708b3587a0a45330bf20b3301d556285d5cd756fa4a
-SIZE (RetroPie-EmulationStation-v2.9.4_GH0.tar.gz) = 852960
+TIMESTAMP = 1703604202
+SHA256 (RetroPie-EmulationStation-v2.11.2_GH0.tar.gz) = 6b632fe68bad5c3e0567e3bb171fe18ad7b2f8b1531d1297a7a91be95bf8734a
+SIZE (RetroPie-EmulationStation-v2.11.2_GH0.tar.gz) = 942655
diff --git a/emulators/emulationstation/files/patch-es-app_src_SystemData.h b/emulators/emulationstation/files/patch-es-app_src_SystemData.h
new file mode 100644
index 000000000000..bef0ab3b2124
--- /dev/null
+++ b/emulators/emulationstation/files/patch-es-app_src_SystemData.h
@@ -0,0 +1,11 @@
+--- es-app/src/SystemData.h.orig	2023-12-18 20:19:11 UTC
++++ es-app/src/SystemData.h
+@@ -9,7 +9,7 @@
+ #include <string>
+ #include <vector>
+ 
+-#include <pugixml/src/pugixml.hpp>
++#include <pugixml.hpp>
+ 
+ class FileData;
+ class FileFilterIndex;
diff --git a/emulators/emulationstation/files/patch-es-core_src_utils_TimeUtil.h b/emulators/emulationstation/files/patch-es-core_src_utils_TimeUtil.h
deleted file mode 100644
index 21e8131fcb9e..000000000000
--- a/emulators/emulationstation/files/patch-es-core_src_utils_TimeUtil.h
+++ /dev/null
@@ -1,10 +0,0 @@
---- es-core/src/utils/TimeUtil.h.orig	2020-11-29 11:32:59 UTC
-+++ es-core/src/utils/TimeUtil.h
-@@ -3,6 +3,7 @@
- #define ES_CORE_UTILS_TIME_UTIL_H
- 
- #include <string>
-+#include <time.h>
- 
- namespace Utils
- {
diff --git a/emulators/emulationstation/pkg-plist b/emulators/emulationstation/pkg-plist
index 93318c21a7ac..dd77d25513cc 100644
--- a/emulators/emulationstation/pkg-plist
+++ b/emulators/emulationstation/pkg-plist
@@ -53,6 +53,7 @@ share/EmulationStation/resources/help/dpad_updown.svg
 share/EmulationStation/resources/mamebioses.xml
 share/EmulationStation/resources/mamedevices.xml
 share/EmulationStation/resources/mamenames.xml
+share/EmulationStation/resources/mameres.py
 share/EmulationStation/resources/off.svg
 share/EmulationStation/resources/on.svg
 share/EmulationStation/resources/opensans_hebrew_condensed_light.ttf



Want to link to this message? Use this URL: <https://mail-archive.FreeBSD.org/cgi/mid.cgi?202401231030.40NAUTtK038742>
diff --git a/emulators/emulationstation/files/patch-es-core_src_utils_FileSystemUtil.cpp b/emulators/emulationstation/files/patch-es-core_src_utils_FileSystemUtil.cpp
index ecdf735fba88..2fb8ec44b076 100644
--- a/emulators/emulationstation/files/patch-es-core_src_utils_FileSystemUtil.cpp
+++ b/emulators/emulationstation/files/patch-es-core_src_utils_FileSystemUtil.cpp
@@ -1,39 +1,85 @@
---- es-core/src/utils/FileSystemUtil.cpp.orig	2020-11-29 11:37:59 UTC
+--- es-core/src/utils/FileSystemUtil.cpp.orig	2023-12-18 20:00:52 UTC
 +++ es-core/src/utils/FileSystemUtil.cpp
-@@ -577,10 +577,10 @@ namespace Utils
- 		bool exists(const std::string& _path)
- 		{
- 			std::string path = getGenericPath(_path);
+@@ -578,10 +578,10 @@ namespace Utils
+ 				CloseHandle(hFile);
+ 			}
+ #else // _WIN32
 -			struct stat64 info;
 +			struct stat info;
  
- 			// check if stat64 succeeded
--			return (stat64(path.c_str(), &info) == 0);
-+			return (stat(path.c_str(), &info) == 0);
- 
- 		} // exists
+-			// check if lstat64 succeeded
+-			if(lstat64(path.c_str(), &info) == 0)
++			// check if lstat succeeded
++			if(lstat(path.c_str(), &info) == 0)
+ 			{
+ 				resolved.resize(info.st_size);
+ 				if(readlink(path.c_str(), (char*)resolved.data(), resolved.size()) > 0)
+@@ -658,9 +658,9 @@ namespace Utils
+ 			if(pathExistsIndex.find(_path) == pathExistsIndex.cend())
+ 			{
+ 				const std::string path = getGenericPath(_path);
+-				struct stat64 info;
+-				// check if stat64 succeeded
+-				pathExistsIndex[_path] = (stat64(path.c_str(), &info) == 0);
++				struct stat info;
++				// check if stat succeeded
++				pathExistsIndex[_path] = (stat(path.c_str(), &info) == 0);
+ 			}
  
-@@ -599,10 +599,10 @@ namespace Utils
+ 			return pathExistsIndex.at(_path);
+@@ -686,10 +686,10 @@ namespace Utils
  		bool isRegularFile(const std::string& _path)
  		{
- 			std::string path = getGenericPath(_path);
+ 			const std::string path = getGenericPath(_path);
+-			struct stat64     info;
++			struct stat     info;
+ 
+-			// check if stat64 succeeded
+-			if(stat64(path.c_str(), &info) != 0)
++			// check if stat succeeded
++			if(stat(path.c_str(), &info) != 0)
+ 				return false;
+ 
+ 			// check for S_IFREG attribute
+@@ -702,10 +702,10 @@ namespace Utils
+ 		bool isDirectory(const std::string& _path)
+ 		{
+ 			const std::string path = getGenericPath(_path);
+-			struct stat64     info;
++			struct stat     info;
+ 
+-			// check if stat64 succeeded
+-			if(stat64(path.c_str(), &info) != 0)
++			// check if stat succeeded
++			if(stat(path.c_str(), &info) != 0)
+ 				return false;
+ 
+ 			// check for S_IFDIR attribute
+@@ -725,10 +725,10 @@ namespace Utils
+ 			if((Attributes != INVALID_FILE_ATTRIBUTES) && (Attributes & FILE_ATTRIBUTE_REPARSE_POINT))
+ 				return true;
+ #else // _WIN32
+-			struct stat64 info;
++			struct stat info;
+ 
+-			// check if lstat64 succeeded
+-			if(lstat64(path.c_str(), &info) != 0)
++			// check if lstat succeeded
++			if(lstat(path.c_str(), &info) != 0)
+ 				return false;
+ 
+ 			// check for S_IFLNK attribute
+@@ -772,10 +772,10 @@ namespace Utils
+ 			// regular files and executables, but not setuid, setgid, shared text
+ 			const mode_t mask = S_IFREG;
+ 			const mode_t mask_exec = S_IXUSR | S_IXGRP | S_IXOTH;
 -			struct stat64 info;
 +			struct stat info;
  
- 			// check if stat64 succeeded
+-			// check if stat64 succeeded
 -			if(stat64(path.c_str(), &info) != 0)
++			// check if stat succeeded
 +			if(stat(path.c_str(), &info) != 0)
  				return false;
  
- 			// check for S_IFREG attribute
-@@ -670,8 +670,8 @@ namespace Utils
- 		} // isHidden
- #ifndef WIN32 // osx / linux
- 		bool isExecutable(const std::string& _path) {
--			struct stat64 st;
--			if(stat64(_path.c_str(), &st) == 0){
-+			struct stat st;
-+			if(stat(_path.c_str(), &st) == 0){
- 				mode_t perm = st.st_mode;
- 				// regular files and executables but not setuid, setgid, shared text (mode 0755)
- 				mode_t mask = S_IFREG | S_IRWXU | S_IRGRP | S_IXGRP | S_IROTH | S_IXOTH;
+ 			// check for mask attributes